summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepassword.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepassword.h')
-rw-r--r--kopete/libkopete/kopetepassword.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kopete/libkopete/kopetepassword.h b/kopete/libkopete/kopetepassword.h
index 149db6f6..de2f96c1 100644
--- a/kopete/libkopete/kopetepassword.h
+++ b/kopete/libkopete/kopetepassword.h
@@ -17,7 +17,7 @@
#ifndef KOPETEPASSWORD_H
#define KOPETEPASSWORD_H
-#include <qobject.h>
+#include <tqobject.h>
#include "kopete_export.h"
namespace KWallet { class Wallet; }
@@ -57,7 +57,7 @@ public:
*
* @deprecated Use the constructor that specifies if a blank password is allowed
*/
- explicit Password( const QString &configGroup, uint maxLength = 0, const char *name = 0 );
+ explicit Password( const TQString &configGroup, uint maxLength = 0, const char *name = 0 );
/**
* Create a new Kopete::Password object.
@@ -67,7 +67,7 @@ public:
* @param allowBlankPassword If this password is allowed to be blank
* @param name The name for this object
*/
- explicit Password( const QString &configGroup, uint maxLength = 0,
+ explicit Password( const TQString &configGroup, uint maxLength = 0,
bool allowBlankPassword = false, const char *name = 0 );
/**
@@ -126,27 +126,27 @@ public:
*
* @param receiver The object to notify when the password request finishes
* @param slot The slot on receiver to call at the end of the request. The signature
* of this function should be slot( const QString &password ). password will
* be the password if successful, or QString::null if failed.
* @param image The icon to display in the dialog when asking for the password
* @param prompt The message to display to the user, asking for a
* password. Can be any Qt RichText string.
* @param source The source the password is taken from if a wrong or
* invalid password is entered or the password could not be found in the wallet
*/
- void request( QObject *receiver, const char *slot, const QPixmap &image,
- const QString &prompt, PasswordSource source = FromConfigOrUser );
+ void request( TQObject *receiver, const char *slot, const TQPixmap &image,
+ const TQString &prompt, PasswordSource source = FromConfigOrUser );
/**
* @brief Start an asynchronous password request without a prompt
*
* Starts an asynchronous password request. Does not pop up a password entry dialog
* if there is no password.
- * @see request(QObject*,const char*,const QPixmap&,const QString&,bool,unsigned int)
+ * @see request(TQObject*,const char*,const TQPixmap&,const TQString&,bool,unsigned int)
* The password given to the provided slot will be NULL if no password could be retrieved for
* some reason, such as the user declining to open the wallet, or no password being found.
*/
- void requestWithoutPrompt( QObject *receiver, const char *slot );
+ void requestWithoutPrompt( TQObject *receiver, const char *slot );
/**
* @return true if the password is remembered, false otherwise.
@@ -163,21 +163,21 @@ public:
/**
* When a password request succeeds, the password is cached. This function
* returns the cached password, if there is one, or QString::null if there
* is not.
*/
- QString cachedValue();
+ TQString cachedValue();
public slots:
/**
* Set the password for this account.
* @param pass If set to QString::null, the password is forgotten unless you
* specified to allow blank passwords. Otherwise, sets the password to
* this value.
*
* Note: this function is asynchronous; changes will not be instant.
*/
- void set( const QString &pass = QString::null );
+ void set( const TQString &pass = TQString::null );
/**
* Unconditionally clears the stored password
@@ -208,7 +208,7 @@ class KopetePasswordRequestBase : public virtual QObject
{
Q_OBJECT
signals:
- void requestFinished( const QString &password );
+ void requestFinished( const TQString &password );
public slots:
virtual void walletReceived( KWallet::Wallet *wallet ) = 0;
virtual void slotOkPressed() = 0;
@@ -126,27 +126,27 @@ public:
* @param receiver The object to notify when the password request finishes
* @param slot The slot on receiver to call at the end of the request. The signature
- * of this function should be slot( const QString &password ). password will
- * be the password if successful, or QString::null if failed.
+ * of this function should be slot( const TQString &password ). password will
+ * be the password if successful, or TQString::null if failed.
* @param image The icon to display in the dialog when asking for the password
* @param prompt The message to display to the user, asking for a
@@ -163,21 +163,21 @@ public:
/**
* When a password request succeeds, the password is cached. This function
- * returns the cached password, if there is one, or QString::null if there
+ * returns the cached password, if there is one, or TQString::null if there
* is not.
*/
@@ -163,21 +163,21 @@ public:
/**
* Set the password for this account.
- * @param pass If set to QString::null, the password is forgotten unless you
+ * @param pass If set to TQString::null, the password is forgotten unless you
* specified to allow blank passwords. Otherwise, sets the password to
* this value.